use crate::structs::cash::Cash;

pub trait Procedures {
    fn create(currency: String, amount: i64) -> Self;
    fn currency(&self) -> String;
    fn amount(&self) -> i64;
}

impl Procedures for Cash {
    fn create(currency: String, amount: i64) -> Self {
        Self {
            currency: String::from(currency),
            amount: amount,
        }
    }

    fn currency(&self) -> String {
        String::from(&self.currency)
    }

    fn amount(&self) -> i64 {
        self.amount
    }
}

impl Cash {
    pub fn new(currency: &str, amount: i64) -> Self {
        Self {
            currency: String::from(currency),
            amount: amount,
        }
    }
}